@@ -55,13 +55,13 @@ def module_contains_display(expression):
     except AttributeError:
         contains_display_attr = False
     contains_display_func = False
-    print(expression.value)
+    print(expression.func.name)
+    contains_display_func = expression.func.name == "display"
     for arg in expression.value.args:
-        print(arg)
-        if isinstance(arg, astroid.nodes.Call):
-            print(arg.func)
-            print(arg.func.attrname)
-            if arg.func.attrname == "display":
+        if isinstance(arg.parent, astroid.nodes.Call):
+            print(arg.parent.func)
+            print(arg.parent.func.name)
+            if arg.parent.func.name == "display":
                 contains_display_func = True
     return (
         contains_func_attribute and contains_attrname and contains_display_attr
